// $Id: ThumbnailDeleteAction.java 17146 2013-03-20 14:47:37Z mike $

package org.faceless.pdf2.viewer2.feature;

import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.beans.*;
import java.awt.event.*;
import javax.swing.undo.*;
import java.util.*;
import java.util.List;
import org.faceless.pdf2.*;
import org.faceless.pdf2.viewer2.*;

/**
 * This feature will allow pages to be deleted via the {@link ThumbnailPanel}.
 *
 * <span class="featurename">The name of this feature is <span class="featureactualname">ThumbnailDeleteAction</span></span>
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.12
 */
public class ThumbnailDeleteAction extends ViewerFeature implements ThumbnailPanel.ThumbnailSelectionAction {

    public ThumbnailDeleteAction() {
        super("ThumbnailDelete");
    }

    public Action getAction(final ThumbnailPanel.View view) {
        if (!view.isFactoryEditable()) {
            return null;
        }

        final AbstractAction action = new AbstractAction(UIManager.getString("PDFViewer.Delete")) {
            {
                putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_DELETE, 0));
                // Note: magic in ThumbnailPanel.View will also use BACKSPACE for this
                // event if it's not otherwise defined. Macs don't have Delete key.
            }
            public void actionPerformed(ActionEvent event) {
                final DocumentPanel docpanel = view.getDocumentPanel();
                final PDF pdf = docpanel.getPDF();

                if (JOptionPane.showConfirmDialog(docpanel, Util.getUIString("PDFViewer.ConfirmDeletePages", view.getSelectedPagesDescription()), view.getName(), JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION) {
                    List l = new ArrayList();
                    for (int i=0;i<view.getComponentCount();i++) {
                        ThumbnailPanel.SinglePagePanel panel = (ThumbnailPanel.SinglePagePanel)view.getComponent(i);
                        if (panel.isSelected()) {
                            l.add(panel.getPage());
                            panel.setSelected(false);
                        }
                    }
                    final List oldpages = new ArrayList(pdf.getPages());
                    pdf.getPages().removeAll(l);
                    final List newpages = new ArrayList(pdf.getPages());
                    final PDFPage beforevisiblepage;
                    if (l.contains(docpanel.getPage())) {
                        docpanel.setPage(beforevisiblepage = pdf.getPage(0));
                    } else {
                        beforevisiblepage = docpanel.getViewport().getRenderingPage();
                    }
                    docpanel.fireUndoableEditEvent(new UndoableEditEvent(docpanel, new AbstractUndoableEdit() {
                        public String getPresentationName() {
                            return UIManager.getString("PDFViewer.Pages");
                        }
                        public boolean canUndo() {
                            return docpanel != null;
                        }
                        public boolean canRedo() {
                            return docpanel != null;
                        }
                        public void undo() {
                            super.undo();
                            // Makes list longer
                            List pages = pdf.getPages();
                            for (int i=0;i<oldpages.size();i++) {
                                PDFPage page = (PDFPage)oldpages.get(i);
                                if (i == pages.size() || pages.get(i) != page) {
                                    pages.add(i, page);
                                }
                            }
                        }
                        public void redo() {
                            super.redo();
                            // Makes list shorter
                            List pages = pdf.getPages();
                            for (int i=0;i<pages.size();i++) {
                                PDFPage page = (PDFPage)pages.get(i);
                                if (i >= newpages.size() || newpages.get(i) != page) {
                                    pages.remove(i--);
                                }
                            }
                            // We may have deleted invisible page
                            if (beforevisiblepage != null) {
                                docpanel.setPage(beforevisiblepage);
                            }
                        }
                    }));
                }
            }
        };

        view.addPropertyChangeListener(new PropertyChangeListener() {
            public void propertyChange(PropertyChangeEvent event) {
                if (event.getPropertyName().equals("selection") || event.getPropertyName().equals("selected")) {
                    // We're only available if deletion won't leave an empty document.
                    PDF pdf = view.getDocumentPanel().getPDF();
                    int select = 0;
                    int total = pdf == null ? 0 : pdf.getNumberOfPages();
                    for (int i=0;i<view.getComponentCount();i++) {
                        ThumbnailPanel.SinglePagePanel panel = (ThumbnailPanel.SinglePagePanel)view.getComponent(i);
                        if (panel.isSelected()) {
                            select++;
                        }
                    }
                    action.setEnabled(select > 0 && select < total && view.isEditable() && view.isDraggable());
                } else if (event.getPropertyName().equals("ancestor") && event.getNewValue() == null) {
                    view.removePropertyChangeListener(this);
                }
            }
        });

        view.getDocumentPanel().addDocumentPanelListener(new DocumentPanelListener() {
            public void documentUpdated(DocumentPanelEvent event) {
                if ("permissionChanged".equals(event.getType())) {
                    action.setEnabled(action.isEnabled() && view.isEditable() && view.isDraggable());
                }
            }
        });

        action.setEnabled(false);
        return action;
    }

}
